pub enum Material {
Color(Color),
Texture(String),
Tileset(Tileset),
}Expand description
Component used by the 2D Renderer to know which material to use when rendering a renderable object.
Variants
Color(Color)
Fill with a color
Texture(String)
Use a texture. Note that this means the target object will need to have uv maps.
Tileset(Tileset)
Tileset Texture. This will be added by the engine on entities with a sprite component.