pub struct Keyboard { /* private fields */ }Expand description
Convenience resource used to keep track of keyboard inputs
Implementations
Sourceimpl Keyboard
impl Keyboard
Sourcepub fn key_pressed(&self, key: &KeyCode) -> bool
pub fn key_pressed(&self, key: &KeyCode) -> bool
Whether or not key is currently pressed
Sourcepub fn keyboard_events(&self) -> &Vec<KeyboardEvent>
pub fn keyboard_events(&self) -> &Vec<KeyboardEvent>
Keyboard events of the current frame
Sourcepub fn on_key_pressed<Body>(&self, key: KeyCode, action: Body)where
Body: FnMut(),
pub fn on_key_pressed<Body>(&self, key: KeyCode, action: Body)where
Body: FnMut(),
convenient function to run action if key is pressed during the current frame
Sourcepub fn on_key_released<Body>(&self, key: KeyCode, action: Body)where
Body: FnMut(),
pub fn on_key_released<Body>(&self, key: KeyCode, action: Body)where
Body: FnMut(),
convenient function to run action if key is released during the current frame