SceneController

Struct SceneController 

pub struct SceneController { /* private fields */ }
SceneController is the Resource used to control the game scenes.

Implementations

Source

impl SceneController

pub fn switch<T: Scene + Default + 'static>(&mut self)

Replace the current scene with the name `` with the scene created from type T. (Useful for level switching). Note that the scene’s stop will happen at the end of the frame.